/*
 * Copyright 2013 Proofpoint Inc.
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package org.kairosdb.core.http.rest.json;


import org.joda.time.DateTimeZone;
import org.kairosdb.core.datastore.TimeUnit;
import org.kairosdb.core.http.rest.validation.TimeUnitRequired;
import org.apache.bval.constraints.NotEmpty;
import org.codehaus.jackson.annotate.JsonCreator;
import org.codehaus.jackson.annotate.JsonProperty;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

public class Sampling
{
	private final DateTimeZone timeZone;
	@Min(1)
	private int duration;

	@TimeUnitRequired
	private String unit;

	@NotNull
	@NotEmpty()
	private String aggregate;

	@JsonCreator
	public Sampling(@JsonProperty("duration") int duration,
			@JsonProperty("unit") String unit,
			@JsonProperty("aggregate") String aggregate,
			@JsonProperty("time_zone") String timeZone)
	{
		this.duration = duration;
		this.unit = unit;
		this.aggregate = aggregate;
		if (timeZone != null)
			this.timeZone = DateTimeZone.forID(timeZone);
		else
			this.timeZone = null;
	}

	@JsonCreator
	public Sampling(@JsonProperty("duration") int duration,
			@JsonProperty("unit") String unit,
			@JsonProperty("aggregate") String aggregate)
	{
		this.duration = duration;
		this.unit = unit;
		this.aggregate = aggregate;
		this.timeZone = null;
	}

	public int getDuration()
	{
		return duration;
	}

	public TimeUnit getUnit()
	{
		return TimeUnit.from(unit);
	}

	public String getAggregate()
	{
		return aggregate;
	}

	public DateTimeZone getTimeZone()
	{
		return timeZone;
	}

	@Override
	public String toString()
	{
		return "Sampling{" +
				"duration=" + duration +
				", unit='" + unit + '\'' +
				", aggregate='" + aggregate + '\'' +
				", timeZone='" + timeZone + '\'' +
				'}';
	}
}